@@ -21,7 +21,7 @@
 #include "picturetest.h"
 #include "kcontacts/picture.h"
 #include <QPainter>
-#include <qtest.h>
+#include <QTest>
 #include <QBuffer>
 
 QTEST_MAIN(PictureTest)
