@@ -24,7 +24,7 @@
 #include "sortmode.h"
 #include "kcontacts_debug.h"
 
-#include <QtCore/QSharedData>
+#include <QSharedData>
 
 using namespace KContacts;
 
@@ -35,7 +35,7 @@ using namespace KContacts;
 //
 
 SortingTraits::Uid::Uid()
-    : d(Q_NULLPTR)
+    : d(nullptr)
 {
 }
 
@@ -56,7 +56,7 @@ bool SortingTraits::Uid::lt(const Addressee &a1, const Addressee &a2)
 }
 
 SortingTraits::Name::Name()
-    : d(Q_NULLPTR)
+    : d(nullptr)
 {
 }
 
@@ -75,7 +75,7 @@ bool SortingTraits::Name::lt(const Addressee &a1, const Addressee &a2)
 }
 
 SortingTraits::FormattedName::FormattedName()
-    : d(Q_NULLPTR)
+    : d(nullptr)
 {
 }
 
@@ -94,7 +94,7 @@ bool SortingTraits::FormattedName::lt(const Addressee &a1, const Addressee &a2)
 }
 
 SortingTraits::FamilyName::FamilyName()
-    : d(Q_NULLPTR)
+    : d(nullptr)
 {
 }
 
@@ -105,8 +105,8 @@ SortingTraits::FamilyName::~FamilyName()
 bool SortingTraits::FamilyName::eq(const Addressee &a1, const Addressee &a2)
 {
     return
-        QString::localeAwareCompare(a1.familyName(), a2.familyName()) == 0 &&
-        QString::localeAwareCompare(a1.givenName(), a2.givenName()) == 0;
+        QString::localeAwareCompare(a1.familyName(), a2.familyName()) == 0
+        && QString::localeAwareCompare(a1.givenName(), a2.givenName()) == 0;
 }
 
 bool SortingTraits::FamilyName::lt(const Addressee &a1, const Addressee &a2)
@@ -120,7 +120,7 @@ bool SortingTraits::FamilyName::lt(const Addressee &a1, const Addressee &a2)
 }
 
 SortingTraits::GivenName::GivenName()
-    : d(Q_NULLPTR)
+    : d(nullptr)
 {
 }
 
@@ -131,8 +131,8 @@ SortingTraits::GivenName::~GivenName()
 bool SortingTraits::GivenName::eq(const Addressee &a1, const Addressee &a2)
 {
     return
-        QString::localeAwareCompare(a1.givenName(), a2.givenName()) == 0 &&
-        QString::localeAwareCompare(a1.familyName(), a2.familyName()) == 0;
+        QString::localeAwareCompare(a1.givenName(), a2.givenName()) == 0
+        && QString::localeAwareCompare(a1.familyName(), a2.familyName()) == 0;
 }
 
 bool SortingTraits::GivenName::lt(const Addressee &a1, const Addressee &a2)
@@ -151,14 +151,14 @@ bool SortingTraits::GivenName::lt(const Addressee &a1, const Addressee &a2)
 //
 //
 
-static Field *sActiveField = Q_NULLPTR;
+static Field *sActiveField = nullptr;
 
 class Q_DECL_HIDDEN AddresseeList::Private : public QSharedData
 {
 public:
     Private()
-        : mReverseSorting(false)
-        , mActiveSortingCriterion(FormattedName)
+        : mActiveSortingCriterion(FormattedName)
+        , mReverseSorting(false)
     {
     }
 
@@ -169,8 +169,8 @@ public:
         mActiveSortingCriterion = other.mActiveSortingCriterion;
     }
 
-    bool mReverseSorting;
     SortingCriterion mActiveSortingCriterion;
+    bool mReverseSorting;
 };
 
 AddresseeList::AddresseeList()
@@ -207,12 +207,10 @@ AddresseeList &AddresseeList::operator=(const AddresseeList &other)
 
 QString AddresseeList::toString() const
 {
-    QString str;
-
-    str += QLatin1String("AddresseeList {\n");
-    str += QStringLiteral("   Reverse Order: %1\n").arg(d->mReverseSorting ?
-            QStringLiteral("true") :
-            QStringLiteral("false"));
+    QString str = QLatin1String("AddresseeList {\n");
+    str += QStringLiteral("   Reverse Order: %1\n").arg(d->mReverseSorting
+                                                        ? QStringLiteral("true")
+                                                        : QStringLiteral("false"));
 
     QString crit;
     switch (d->mActiveSortingCriterion) {
@@ -307,8 +305,8 @@ void AddresseeList::sortByTrait()
         iterator j2 = j1;
         ++j2;
         while (j1 != i2) {
-            if ((!d->mReverseSorting && Trait::lt(*j2, *j1)) ||
-                    (d->mReverseSorting && Trait::lt(*j1, *j2))) {
+            if ((!d->mReverseSorting && Trait::lt(*j2, *j1))
+                || (d->mReverseSorting && Trait::lt(*j1, *j2))) {
                 qSwap(*j1, *j2);
             }
             ++j1;
@@ -328,28 +326,28 @@ void AddresseeList::sortByField(Field *field)
 
     sActiveField = field;
 
-    if (count() == 0) {
+    if (isEmpty()) {
         return;
     }
 
     KContacts::FieldSortMode *mode = new KContacts::FieldSortMode(sActiveField, !d->mReverseSorting);
 
     KContacts::Addressee::setSortMode(mode);
-    qSort(*this);
-    KContacts::Addressee::setSortMode(Q_NULLPTR);
+    std::sort((*this).begin(), (*this).end());
+    KContacts::Addressee::setSortMode(nullptr);
 
     delete mode;
 }
 
 void AddresseeList::sortByMode(SortMode *mode)
 {
-    if (count() == 0) {
+    if (isEmpty()) {
         return;
     }
 
     KContacts::Addressee::setSortMode(mode);
-    qSort(*this);
-    KContacts::Addressee::setSortMode(Q_NULLPTR);
+    std::sort((*this).begin(), (*this).end());
+    KContacts::Addressee::setSortMode(nullptr);
 }
 
 SortingCriterion AddresseeList::sortingCriterion() const
