@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+    Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -54,7 +54,7 @@ public:
     Q_REQUIRED_RESULT bool operator==(const Lang &other) const;
     Q_REQUIRED_RESULT bool operator!=(const Lang &other) const;
 
-    Q_REQUIRED_RESULT Lang &operator=(const Lang &other);
+    Lang &operator=(const Lang &other);
 
     Q_REQUIRED_RESULT QString toString() const;
 private:
